reporter

package
v0.5.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 6, 2024 License: MIT Imports: 7 Imported by: 0

Documentation

Overview

Package reporter provides functions for generating coverage reports.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func NewCLIConfig added in v0.3.1

func NewCLIConfig() (*config.Config, error)

NewCLIConfig creates a new configuration based on the command-line arguments.

func ParseCutlines added in v0.3.0

func ParseCutlines(cutlines string) (*config.Cutlines, error)

ParseCutlines parses the cutlines argument.

func ParseIgnores added in v0.5.0

func ParseIgnores(ignores string) []string

ParseIgnores parses the ignores argument.

func Report added in v0.2.0

func Report(cfg *config.Config) error

Report generates a coverage report using the given configuration.

Types

This section is empty.

Directories

Path Synopsis
Package config provides types and functions for working with configuration data.
Package config provides types and functions for working with configuration data.
This code is adapted from the Go standard library's cover tool: https://github.com/golang/go/blob/master/src/cmd/cover/func.go
This code is adapted from the Go standard library's cover tool: https://github.com/golang/go/blob/master/src/cmd/cover/func.go

Jump to