config

package
v0.5.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 6, 2024 License: MIT Imports: 0 Imported by: 0

Documentation

Overview

Package config provides types and functions for working with configuration data.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Config added in v0.3.1

type Config struct {
	Input    string
	Output   string
	Root     string
	Cutlines *Cutlines
	Ignores  []string
}

Config represents the configuration for a program.

type Cutlines

type Cutlines struct {
	Safe    float64
	Warning float64
}

Cutlines represents the values for safe, warning and danger.

Jump to