Documentation
¶
Overview ¶
Package reporter provides functions for generating coverage reports.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewCLIConfig ¶ added in v0.3.1
NewCLIConfig creates a new configuration based on the command-line arguments.
func ParseCutlines ¶ added in v0.3.0
ParseCutlines parses the cutlines argument.
func ParseIgnores ¶ added in v0.5.0
ParseIgnores parses the ignores argument.
Types ¶
This section is empty.
Directories
¶
| Path | Synopsis |
|---|---|
|
Package config provides types and functions for working with configuration data.
|
Package config provides types and functions for working with configuration data. |
|
This code is adapted from the Go standard library's cover tool: https://github.com/golang/go/blob/master/src/cmd/cover/func.go
|
This code is adapted from the Go standard library's cover tool: https://github.com/golang/go/blob/master/src/cmd/cover/func.go |
Click to show internal directories.
Click to hide internal directories.